import { InputHTMLAttributes, ChangeEventHandler, FC } from 'react';
declare type BaseElement = HTMLInputElement;
declare type BaseProps = InputHTMLAttributes<BaseElement>;
export declare type CheckboxChangeHandler = ChangeEventHandler<BaseElement>;
export declare type CheckboxValueChangeHandler = (value: boolean) => void;
export interface CheckboxProps extends BaseProps {
    /**
     * Specifies the name of an input element.
     */
    readonly name?: BaseProps['name'];
    /**
     * `class` to be passed to the component.
     */
    readonly className?: string;
    /**
     * If `true`, the component is checked.
     */
    readonly checked: boolean;
    /**
     * Native change handler that can be used by formik etc.
     */
    readonly onChange?: CheckboxChangeHandler;
    /**
     * A label for the checkbox
     */
    readonly label?: string;
    /**
     * If `true`, the component is partially checked.
     */
    readonly partial?: boolean;
    /**
     * Set as true when checkbox checked as checked.
     */
    readonly onCheckedValueChange?: CheckboxValueChangeHandler;
    /**
     * Set as true when checkbox checked as partial.
     */
    readonly onPartialValueChange?: CheckboxValueChangeHandler;
}
export declare const Checkbox: FC<CheckboxProps>;
export declare const CheckboxField: FC<CheckboxProps & import("../utils").FieldProps>;
export {};
