"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PopOver = void 0;
var _react = require("react");
var _reactDom = _interopRequireDefault(require("react-dom"));
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _Practical = require("../Practical");
var _utils = require("./utils");
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["anchorEl", "inline", "horizontalPosition", "verticalPosition", "horizontalAlignment", "verticalAlignment", "onPosition", "onScroll", "children"];
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var PopOverContainer = _styledComponents.default.div.withConfig({
  displayName: "PopOver__PopOverContainer",
  componentId: "sc-1gkk5kl-0"
})(["position:fixed;"]);

/**
 * Pop-over component
 *
 * Used to render some content positioned relative to an anchor, but as a child
 * of the document. By default the PopOver content is positioned below the
 * anchor aligned to the left. When the content would overflow the document, it's
 * repositioned stay within the document boundaries.
 */

var PopOver = _ref => {
  var {
      anchorEl,
      inline = false,
      horizontalPosition = 'left',
      verticalPosition = 'bottom',
      horizontalAlignment = 'left',
      verticalAlignment = 'top',
      onPosition,
      onScroll,
      children
    } = _ref,
    props = _objectWithoutProperties(_ref, _excluded);
  var [popOverContainer, setPopOverContainer] = (0, _react.useState)(null);
  var {
    el: layerRoot
  } = (0, _react.useContext)(_Practical.LayerContext);
  var position = (0, _react.useCallback)(() => {
    // Position the pop-over element synchronously
    if (anchorEl !== null && popOverContainer !== null) {
      if (onPosition === undefined) {
        (0, _utils.anchorPosition)(anchorEl, popOverContainer, {
          horizontalPosition,
          verticalPosition,
          horizontalAlignment,
          verticalAlignment
        });
        return;
      }
      onPosition(anchorEl, popOverContainer);
    }
  }, [horizontalPosition, verticalPosition, horizontalAlignment, verticalAlignment, anchorEl, onPosition, popOverContainer]);
  (0, _utils.useOnScrollEffect)(anchorEl, onScroll !== undefined ? onScroll : () => {
    /** */
  });

  // Used when resizing the parent anchorEl
  (0, _utils.useOnResizeParentEffect)(anchorEl, position);
  (0, _utils.useOnResizeEffect)(popOverContainer, position);

  // Reposition on initialize
  (0, _react.useLayoutEffect)(() => {
    position();
  }, [position, popOverContainer]);
  var popOverElement = (0, _react.useMemo)(() => /*#__PURE__*/(0, _jsxRuntime.jsx)(PopOverContainer, _objectSpread(_objectSpread({
    ref: setPopOverContainer
  }, props), {}, {
    children: children
  })), [children, props]);

  // When the layer element is not available, there is no layer yet.
  if (layerRoot === null) {
    return null;
  }

  // Render the pop-over at the same DOM-level as anchorEl
  if (inline && anchorEl !== null) {
    return popOverElement;
  }
  return /*#__PURE__*/_reactDom.default.createPortal(popOverElement, layerRoot);
};
exports.PopOver = PopOver;