"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ColumnResizerRow = void 0;
var _react = require("react");
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _reactHooksShareable = require("react-hooks-shareable");
var _designparams = require("../designparams");
var _dimensions = require("./dimensions");
var _context = require("./context");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * Clip the translation of a divider so that it remains
 * within the total width of the two columns it divides.
 *
 * @param tx Divider translation
 * @param divider Divider
 */
var clipTranslation = (tx, divider, minWidth) => {
  var {
    before,
    after
  } = divider;
  var txMin = minWidth - before;
  var txMax = after - minWidth;
  return Math.min(Math.max(txMin, tx), txMax);
};

/*******************************************************************************
 *
 * Column resizing.
 *
 ******************************************************************************/

var ResizeContainer = _styledComponents.default.div.attrs(_ref => {
  var {
    left
  } = _ref;
  return {
    style: {
      left: "".concat(left - 8, "px")
    }
  };
}).withConfig({
  displayName: "ColumnResizerRow__ResizeContainer",
  componentId: "sc-1khw7xf-0"
})(["display:relative;position:absolute;width:16px;top:0;height:100%;pointer-events:none;"]);

/**
 * ResizeHandle
 *
 * A special component to keep track of the size of its element
 * and pass it to a function that can alter the size globally.
 */
var ResizeHandle = _styledComponents.default.div.withConfig({
  displayName: "ColumnResizerRow__ResizeHandle",
  componentId: "sc-1khw7xf-1"
})(["position:absolute;width:16px;top:0;left:0;height:", ";cursor:ew-resize;pointer-events:all;"], _designparams.componentSize.large);

/**
 * ResizeMarker
 *
 * A vertical line marking the edge of the new column.
 */
var ResizeMarker = _styledComponents.default.div.withConfig({
  displayName: "ColumnResizerRow__ResizeMarker",
  componentId: "sc-1khw7xf-2"
})(["display:", ";position:absolute;width:1px;top:0;bottom:0;left:8px;background-color:", ";", ":hover + &{display:unset;}"], _ref2 => {
  var {
    dragging
  } = _ref2;
  return dragging ? 'unset' : 'none';
}, _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.color.background01();
}, /* sc-selector */ResizeHandle);

/**
 * widthLookup
 *
 * This lookup returns the size a column would need to
 * accommodate it's largest element without overflow.
 */
var widthLookup = (tableRef, separator) => {
  var _tableRef$current, _tableRef$current2;
  var column1Elements = (_tableRef$current = tableRef.current) === null || _tableRef$current === void 0 ? void 0 : _tableRef$current.querySelectorAll("[data-col=\"".concat(separator, "\"]"));
  var maxColumn1Width = 0;
  for (var el of column1Elements !== null && column1Elements !== void 0 ? column1Elements : []) {
    maxColumn1Width = Math.max(maxColumn1Width, el.children[0].getBoundingClientRect().width);
  }
  var column2Elements = (_tableRef$current2 = tableRef.current) === null || _tableRef$current2 === void 0 ? void 0 : _tableRef$current2.querySelectorAll("[data-col=\"".concat(separator + 1, "\"]"));
  var maxColumn2Width = 0;
  for (var _el of column2Elements !== null && column2Elements !== void 0 ? column2Elements : []) {
    maxColumn2Width = Math.max(maxColumn2Width, _el.children[0].getBoundingClientRect().width);
  }
  return [maxColumn1Width + _dimensions.TABLE_DIMENSIONS.PADDING_LEFT, maxColumn2Width + _dimensions.TABLE_DIMENSIONS.PADDING_LEFT];
};
var updateWidths = _ref4 => {
  var {
    tableRef,
    separator,
    currentSizes,
    minColumnWidth
  } = _ref4;
  var [col1, col2] = widthLookup(tableRef, separator);
  var prevCol1 = currentSizes[separator];
  var prevCol2 = currentSizes[separator + 1];
  var newCol1 = Math.min(Math.max(col1, minColumnWidth), prevCol1);
  var newCol2 = Math.min(Math.max(col2, minColumnWidth), prevCol2);
  var scaleFactor = (prevCol1 + prevCol2) / (newCol1 + newCol2);
  var newWidths = [...currentSizes];
  newWidths[separator] = newCol1 * scaleFactor;
  newWidths[separator + 1] = newCol2 * scaleFactor;
  return newWidths;
};

/*
 * ColumnResizer
 *
 * A draggable resize handle that will dispatch a new
 * column width when dragging ends. During dragging,
 * a resize marker is shown to follow the change in width.
 */

var ColumnResizer = _ref5 => {
  var {
    divider,
    setDragging,
    onDragEnd,
    index
  } = _ref5;
  var {
    minColumnWidth,
    dispatchWidthsAction,
    columnWidths,
    tableRef
  } = (0, _react.useContext)(_context.TableContext);
  var [[tx], onDragStart, dragging] = (0, _reactHooksShareable.useDraggable)(onDragEnd);
  var txClipped = clipTranslation(tx, divider, minColumnWidth);
  (0, _react.useEffect)(() => {
    setDragging(dragging);
    if (dragging) {
      document.body.style.cursor = 'ew-resize';
      return () => {
        document.body.style.cursor = '';
      };
    }
  }, [dragging, setDragging]);
  var optimizeColWidths = (0, _react.useCallback)(() => {
    if (tableRef === undefined) return;
    dispatchWidthsAction({
      type: _context.WidthActionType.UPDATE_WIDTHS,
      widths: updateWidths({
        tableRef,
        separator: index,
        currentSizes: columnWidths,
        minColumnWidth
      })
    });
  }, [tableRef, minColumnWidth, index, columnWidths, dispatchWidthsAction]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(ResizeContainer, {
    onDoubleClick: optimizeColWidths,
    left: divider.offset + txClipped,
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(ResizeHandle, {
      onPointerDown: onDragStart
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(ResizeMarker, {
      dragging: dragging
    })]
  });
};

/**
 * ColumnResizerRow
 *
 * A collection of resize handlers.
 */

var ColumnResizerRow = _ref6 => {
  var {
    setDragging
  } = _ref6;
  var {
    minColumnWidth,
    columnWidths,
    dispatchWidthsAction,
    onSelect,
    onWidthsChange
  } = (0, _react.useContext)(_context.TableContext);

  /**
   * The global offset of all resize handles.
   * This is used e.g. when there is a column
   * of checkboxes that needs to be taken into account.
   */
  var globalOffset = _dimensions.TABLE_DIMENSIONS.PADDING_LEFT + (onSelect !== undefined ? _dimensions.TABLE_DIMENSIONS.SELECT_WIDTH : 0);
  var dividers = (0, _react.useMemo)(() => {
    var result = [];
    var offset = globalOffset;
    for (var i = 0; i < columnWidths.length - 1; i += 1) {
      offset = offset + columnWidths[i];
      result.push({
        offset,
        before: columnWidths[i],
        after: columnWidths[i + 1]
      });
    }
    return result;
  }, [columnWidths, globalOffset]);
  var moveDivider = (0, _react.useCallback)((x, dividerIndex) => {
    var divider = dividers[dividerIndex];
    var xClipped = clipTranslation(x, divider, minColumnWidth);
    dispatchWidthsAction({
      type: _context.WidthActionType.UPDATE_WIDTHS,
      widths: {
        [dividerIndex]: divider.before + xClipped,
        [dividerIndex + 1]: divider.after - xClipped
      },
      onWidthsChange
    });
  }, [dividers, dispatchWidthsAction, minColumnWidth, onWidthsChange]);
  var dragEndHandlers = (0, _react.useMemo)(() => {
    return [...Array(dividers.length).keys()].map(i => _ref7 => {
      var [tx] = _ref7;
      return moveDivider(tx, i);
    });
  }, [dividers.length, moveDivider]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_jsxRuntime.Fragment, {
    children: dividers.map((divider, i) => {
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(ColumnResizer, {
        setDragging: setDragging,
        index: i,
        divider: divider,
        onDragEnd: dragEndHandlers[i]
      }, "".concat(i, ":").concat(divider.offset));
    })
  });
};
exports.ColumnResizerRow = ColumnResizerRow;