"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Typography = void 0;
var _styledComponents = _interopRequireWildcard(require("styled-components"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var TYPOGRAPHY_VARIANTS = {
  /**
   * Paragraph
   *
   * The sort of text that appears in blocks inside
   * e.g. a modal, should be easily readable.
   */
  'default-text': {
    as: 'p',
    css: (0, _styledComponents.css)(["font-size:", ";line-height:", ";"], _ref => {
      var {
        theme
      } = _ref;
      return theme.font.size.regular;
    }, _ref2 => {
      var {
        theme
      } = _ref2;
      return theme.font.lineHeight.large;
    })
  },
  /**
   * Descriptive
   *
   * The sort of text that elaborates on another
   * piece of information or context.
   * Should be small to be able to show a lot.
   */
  caption: {
    as: 'p',
    css: (0, _styledComponents.css)(["font-size:", ";line-height:", ";"], _ref3 => {
      var {
        theme
      } = _ref3;
      return theme.font.size.small;
    }, _ref4 => {
      var {
        theme
      } = _ref4;
      return theme.font.lineHeight.small;
    })
  },
  /**
   * Dialog heading
   */
  'dialog-heading': {
    as: 'p',
    css: (0, _styledComponents.css)(["font-size:", ";line-height:", ";"], _ref5 => {
      var {
        theme
      } = _ref5;
      return theme.font.size.larger;
    }, _ref6 => {
      var {
        theme
      } = _ref6;
      return theme.font.lineHeight.larger;
    })
  },
  /**
   * Page heading
   */
  'page-heading': {
    as: 'p',
    css: (0, _styledComponents.css)(["font-size:", ";line-height:", ";"], _ref7 => {
      var {
        theme
      } = _ref7;
      return theme.font.size.larger;
    }, _ref8 => {
      var {
        theme
      } = _ref8;
      return theme.font.lineHeight.larger;
    })
  },
  /**
   * Chip or tag text
   *
   * Text appearing as chip or tag.
   * Should be small text.
   */
  'chip-tag-text': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";line-height:", ";white-space:nowrap;"], _ref9 => {
      var {
        theme
      } = _ref9;
      return theme.font.size.small;
    }, _ref10 => {
      var {
        theme
      } = _ref10;
      return theme.font.lineHeight.smaller;
    })
  },
  /**
   * Explanatory text
   *
   * Text appearing as explanatory text, e.g. error message in a field.
   * Should be small text.
   */
  'explanatory-text': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";line-height:", ";white-space:nowrap;"], _ref11 => {
      var {
        theme
      } = _ref11;
      return theme.font.size.small;
    }, _ref12 => {
      var {
        theme
      } = _ref12;
      return theme.font.lineHeight.small;
    })
  },
  /**
   * Navigation group
   *
   * Text appearing as navigation group name, e.g. Group name on sidebar.
   */
  'navigation-group': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";line-height:", ";white-space:nowrap;"], _ref13 => {
      var {
        theme
      } = _ref13;
      return theme.font.size.small;
    }, _ref14 => {
      var {
        theme
      } = _ref14;
      return theme.font.lineHeight.smaller;
    })
  },
  /**
   * Navigation label
   *
   * Standard size used for text labels,
   * short descriptions connected to another element.
   * e.g. Label on sidebar
   */
  'navigation-label': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";line-height:", ";white-space:nowrap;"], _ref15 => {
      var {
        theme
      } = _ref15;
      return theme.font.size.regular;
    }, _ref16 => {
      var {
        theme
      } = _ref16;
      return theme.font.lineHeight.small;
    })
  },
  /**
   * Card title
   */
  'card-title': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";font-weight:", ";line-height:", ";white-space:nowrap;"], _ref17 => {
      var {
        theme
      } = _ref17;
      return theme.font.size.regular;
    }, _ref18 => {
      var {
        theme
      } = _ref18;
      return theme.font.fontWeight.semibold;
    }, _ref19 => {
      var {
        theme
      } = _ref19;
      return theme.font.lineHeight.small;
    })
  },
  /**
   * Group title
   *
   * Text appearing as a title of some fields or some group in Dialog.
   */
  'group-title': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";font-weight:", ";line-height:", ";white-space:nowrap;"], _ref20 => {
      var {
        theme
      } = _ref20;
      return theme.font.size.regular;
    }, _ref21 => {
      var {
        theme
      } = _ref21;
      return theme.font.fontWeight.semibold;
    }, _ref22 => {
      var {
        theme
      } = _ref22;
      return theme.font.lineHeight.small;
    })
  },
  /**
   * Column heading in a table
   */
  'column-heading': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";font-weight:", ";line-height:", ";white-space:nowrap;"], _ref23 => {
      var {
        theme
      } = _ref23;
      return theme.font.size.small;
    }, _ref24 => {
      var {
        theme
      } = _ref24;
      return theme.font.fontWeight.normal;
    }, _ref25 => {
      var {
        theme
      } = _ref25;
      return theme.font.lineHeight.smaller;
    })
  },
  /**
   * Header title
   */
  'header-title': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";font-weight:", ";line-height:", ";white-space:nowrap;"], _ref26 => {
      var {
        theme
      } = _ref26;
      return theme.font.size.regular;
    }, _ref27 => {
      var {
        theme
      } = _ref27;
      return theme.font.fontWeight.semibold;
    }, _ref28 => {
      var {
        theme
      } = _ref28;
      return theme.font.lineHeight.small;
    })
  },
  /**
   * Button
   *
   * Text appearing inside a button
   */
  'button-text': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";font-weight:", ";line-height:", ";white-space:nowrap;"], _ref29 => {
      var {
        theme
      } = _ref29;
      return theme.font.size.large;
    }, _ref30 => {
      var {
        theme
      } = _ref30;
      return theme.font.fontWeight.semibold;
    }, _ref31 => {
      var {
        theme
      } = _ref31;
      return theme.font.lineHeight.large;
    })
  },
  /**
   * Compact label
   *
   * Label where space is limited
   */
  'compact-label': {
    as: 'span',
    css: (0, _styledComponents.css)(["font-size:", ";line-height:", ";"], _ref32 => {
      var {
        theme
      } = _ref32;
      return theme.font.size.smaller;
    }, _ref33 => {
      var {
        theme
      } = _ref33;
      return theme.font.lineHeight.smallest;
    })
  }
};

/**
 *
 * Generic typography
 *
 */

var Typography = _styledComponents.default.p.attrs(_ref34 => {
  var {
    variant = 'default-text'
  } = _ref34;
  return {
    as: TYPOGRAPHY_VARIANTS[variant].as
  };
}).withConfig({
  displayName: "Typography",
  componentId: "sc-xea1fh-0"
})(["font-family:", ";font-size:", ";line-height:", ";overflow:hidden;text-overflow:ellipsis;margin:0;", ""], _ref35 => {
  var {
    theme
  } = _ref35;
  return theme.font.family;
}, _ref36 => {
  var {
    theme
  } = _ref36;
  return theme.font.size.regular;
}, _ref37 => {
  var {
    theme
  } = _ref37;
  return theme.font.lineHeight.large;
}, _ref38 => {
  var {
    variant = 'default-text'
  } = _ref38;
  return TYPOGRAPHY_VARIANTS[variant].css;
});
exports.Typography = Typography;