"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateDefaultTheme = exports.font = exports.defaultTheme = void 0;
var _color = require("./color");
/**
 * Default theming
 */
var font = {
  size: {
    smaller: '11px',
    small: '12px',
    regular: '13px',
    large: '14px',
    larger: '21px'
  },
  lineHeight: {
    smallest: '15px',
    smaller: '17px',
    small: '18px',
    medium: '21px',
    large: '22px',
    larger: '32px'
  },
  fontWeight: {
    normal: 400,
    semibold: 600,
    bold: 700
  },
  family: 'Open Sans, Helvetica, arial, sans-serif',
  button: {
    primary: {
      textTransform: 'none'
    },
    secondary: {
      default: {
        textTransform: 'none'
      },
      accent: {
        textTransform: 'none'
      }
    }
  },
  tableHeader: {
    textTransform: 'none'
  }
};

// The type guards `as ColorName` should not be needed with TypeScript 4.2.0,
// however, because of https://github.com/yarnpkg/berry/issues/2384 we cannot
// upgrade to 4.2.0-beta yet.
// FIXME: remove `as ColorName` type guards when TypeScript 4.2 is used.
exports.font = font;
var generateDefaultColors = color => {
  return {
    text00: _color.palette.white,
    text01: _color.palette.grey16,
    text02: _color.palette.grey24,
    text03: _color.palette.grey32,
    text04: _color.palette.grey40,
    text05: _color.palette.grey48,
    text06: _color.palette.grey16,
    textLink: _color.palette["".concat(color, "600")],
    textLinkHover: _color.palette["".concat(color, "700")],
    textPrimary: _color.palette["".concat(color, "800")],
    textError: _color.palette.red700,
    background: _color.palette.white,
    background00: _color.palette.white,
    background01: _color.palette.grey94,
    background02: _color.palette.grey96,
    background03: _color.palette.grey98,
    background04: _color.palette.grey98,
    background05: _color.palette.white,
    backgroundPrimary: _color.palette.grey96,
    backgroundError: _color.palette.red50,
    element01: _color.palette.grey40,
    element10: _color.palette.grey98,
    element11: _color.palette.grey80,
    element12: _color.palette.grey90,
    element13: _color.palette.grey72,
    element14: _color.palette.grey64,
    element15: _color.palette.grey98,
    element16: _color.palette.grey98,
    elementPrimary: _color.palette["".concat(color, "500")],
    elementHalfPrimary: _color.palette["".concat(color, "600")],
    elementError: _color.palette.red700,
    elementSuccess: _color.palette.green700,
    elementWarning: _color.palette.amber500,
    elementAccent: _color.palette["".concat(color, "500")],
    elementBorder: _color.palette.transparent
  };
};
var generateDefaultTheme = color => ({
  font,
  color: generateDefaultColors(color),
  shadow: {
    card: '0 2px 6px 0 rgba(235, 237, 240, 1)',
    dialog: '0 2px 12px 0 rgba(0, 0, 0, 0.24)',
    dialogHeaderFooter: '0 0 4px 2px rgba(0, 0, 0, 0.08)',
    header: '0px 2px 6px rgba(0, 0, 0, 0.16)',
    knobOff1: '0 1px 4px 0 rgba(0, 0, 0, 0.24)',
    knobOff2: '0 1px 2px 0 rgba(0, 0, 0, 0.32)',
    knobOn1: '0 1px 2px 0 rgba(0, 0, 0, 0.16)',
    knobOn2: '0 1px 2px 0 rgba(0, 0, 0, 0.24)',
    knobOn3: '0 1px 1px 0 rgba(0, 0, 0, 0.24)',
    menu: '0 2px 16px 0px rgba(0, 0, 0, 0.24)',
    primaryButton: '0 2px 6px 0 rgba(0, 0, 0, 0.16)',
    selectList: '0 2px 4px 0 rgba(0, 0, 0, 0.24)',
    tab: '0 2px 6px 0 rgba(188, 195, 204, 0.32)',
    tableRow: '0 1px 4px 0 rgba(0, 0, 0, 0.16)',
    toast: '0 4px 24px 0 rgba(0, 0, 0, 0.08)',
    tooltip: '0 4px 24px 0 rgba(0, 0, 0, 0.08)'
  },
  compact: false,
  selectMarker: 'background'
});
exports.generateDefaultTheme = generateDefaultTheme;
var defaultTheme = generateDefaultTheme('deepPurple');
exports.defaultTheme = defaultTheme;